pub enum MlsError {
Show 22 variants
Io(Error),
Serde(Error),
Mls(MlsError),
CryptoProviderError(String),
IdentityProviderError(AuthError),
CiphersuiteUnavailable,
ClientNotInitialized,
GroupNotExists,
NoGroupUpdatePayload,
NoWelcomeMessage,
UnknownPayloadType,
StorageIo(Error),
TokenRetrievalFailed(String),
FileSyncFailed(String),
IdentifierNotFound(String),
CredentialNotFound,
NotBasicCredential,
InvalidUtf8(Utf8Error),
VerificationFailed(String),
ExternalSenderFailed(String),
PublicKeyMismatch {
expected: String,
found: String,
},
ExternalCommitNotSupported,
}Variants
Io(Error)
Serde(Error)
Mls(MlsError)
CryptoProviderError(String)
IdentityProviderError(AuthError)
ClientNotInitialized
GroupNotExists
NoGroupUpdatePayload
NoWelcomeMessage
UnknownPayloadType
StorageIo(Error)
TokenRetrievalFailed(String)
FileSyncFailed(String)
IdentifierNotFound(String)
CredentialNotFound
NotBasicCredential
InvalidUtf8(Utf8Error)
VerificationFailed(String)
ExternalSenderFailed(String)
PublicKeyMismatch
ExternalCommitNotSupported
Implementations
Sourceimpl MlsError
impl MlsError
Sourcepub fn crypto_provider<E: Error + Send + Sync + 'static>(e: E) -> Self
pub fn crypto_provider<E: Error + Send + Sync + 'static>(e: E) -> Self
Helper to construct a crypto provider error from any error implementing std::error::Error.
Sourcepub fn token_retrieval_failed<T: Display>(t: T) -> Self
pub fn token_retrieval_failed<T: Display>(t: T) -> Self
Helper to construct a token retrieval failure from any displayable value.
Sourcepub fn identifier_not_found<I: Display>(id: I) -> Self
pub fn identifier_not_found<I: Display>(id: I) -> Self
Helper to construct an identifier not found error.
Sourcepub fn verification_failed<R: Display>(reason: R) -> Self
pub fn verification_failed<R: Display>(reason: R) -> Self
Helper to construct a verification failed error.
Sourcepub fn external_sender_failed<R: Display>(reason: R) -> Self
pub fn external_sender_failed<R: Display>(reason: R) -> Self
Helper to construct an external sender validation failure.